#
# spec file for package gloox
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 18
Name:           gloox
Version:        1.0.28
Release:        1.1
Summary:        High-level XMPP Library for C++
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://camaya.net/gloox
Source:         https://camaya.net/download/gloox-%{version}.tar.bz2
Source200:      baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel >= 2.12
BuildRequires:  libidn-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel

%description
gloox is a portable high-level Jabber/XMPP library for C++. It is fully
compliant with the XMPP RFCs, supports all of the XMPP features (including
SRV lookups, TLS, SASL, roster management, and privacy lists), and implements
several XEPs that make it ideal for writing any kind of Jabber/XMPP client
or component.

%package -n lib%{name}%{soname}
Summary:        High-level XMPP Library for C++
Group:          System/Libraries

%description -n lib%{name}%{soname}
gloox is a portable high-level Jabber/XMPP library for C++. It is fully
compliant with the XMPP RFCs, supports all of the XMPP features (including
SRV lookups, TLS, SASL, roster management, and privacy lists), and implements
several XEPs that make it ideal for writing any kind of Jabber/XMPP client
or component.

%package devel
Summary:        High-level XMPP Library for C++
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}
Requires:       libstdc++-devel

%description devel
gloox is a portable high-level Jabber/XMPP library for C++. It is fully
compliant with the XMPP RFCs, supports all of the XMPP features (including
SRV lookups, TLS, SASL, roster management, and privacy lists), and implements
several XEPs that make it ideal for writing any kind of Jabber/XMPP client
or component.

%prep
%autosetup -n gloox-%{version}

%build
export SUSE_ASNEEDED=0
%configure --enable-shared --disable-static --enable-getaddrinfo --without-examples
%make_build

%install
%make_install

rm -f "%{buildroot}%{_libdir}/libgloox".{a,la}

h=%{_datadir}/doc/licenses/md5/$(md5sum COPYING|cut -f1 -d" ")
test -e "$h" && ln -s -f "$h" COPYING

%check
%make_build test

%post   -n lib%{name}%{soname} -p /sbin/ldconfig
%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%files -n lib%{name}%{soname}
%license COPYING
%doc AUTHORS README ChangeLog TODO
%{_libdir}/libgloox.so.%{soname}
%{_libdir}/libgloox.so.%{soname}.*.*

%files devel
%{_bindir}/gloox-config
%{_includedir}/gloox
%{_libdir}/libgloox.so
%{_libdir}/pkgconfig/gloox.pc

%changelog
* Thu Dec 28 2023 jun wang <junguo.wang@suse.com>
- Update to version 1.0.28
  * fixed SCRAM-SHA-1-PLUS with OpenSSL and TLS 1.3 (fixes #302)
  * remove obsolete patch gloox-1.0.24-fix-gcc12-time.patch
* Sat Aug 13 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add gloox-1.0.24-fix-gcc12-time.patch: Fix build with GCC 12.
- Disable build of examples as they are not installed.
- Drop obsolete build requirements: autoconf, automake.
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.24:
  - Tag: fixed XML namespace for attribute with empty namespace (fixes #278) (thanks to drizt72)
  - PubSub::Event: add simple ctor (thanks to Daniel Kraft)
  - PubSub::Manager: fixed subscription error case handling (thanks to Daniel Kraft)
  - PubSub: fixed support for instant nodes
  - RosterManager: fixed behavior if subscription attribute is absent in roster item
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.0.23:
  * fixed a memory leak in dns.cpp
  * fixed session management/stream resumption
  * ClientBase: fix honorThreadID
  * TLSGnuTLS: disabled TLS 1.3 for now, as there are
    connection issues with it
  Check the ChangeLog file for other changes.
- Drop gloox-fix_TLSGnuTLS_test.patch. Merged upstream.
* Fri Aug 17 2018 astieger@suse.com
- update to 1.0.21:
  * InBandBytestream: error handling corrected
  * doc fix: CertInfo::date_from/to set correctly when using OpenSSL
- drop iksemel from spec, not required
* Tue Feb 13 2018 vcizek@suse.com
- fix gnutls test broken with gnutls 3.6 (bsc#1078834)
  * since 3.6 ANON key exchange algorithms have to be turned on explicitly
  * add gloox-fix_TLSGnuTLS_test.patch
* Fri Oct 13 2017 mailaender@opensuse.org
- Update to 1.0.20
  * BytestreamDataHandler: added callback for acknowledged packets
  * ConnectionTCPClient: compile fix for Win32 (broken in 1.0.19)
  * ConnectionTCPClient: no-block fix
  * use ws2_32.lib instead of ws_32.lib on Win32
- Changes from 1.0.19
  * ConnectionTCPServer: cleanup
  * lots of compile-time warnings removed
  * TLSOpenSSL: made it speak TLSv1.1 and 1.2 again (thanks to Nicolas Belouin)
  * added Client State Indication (XEP-0352)
  * CertInfo struct: fixed protocol version when using OpenSSL
  * TLSOpenSSL: fixed compilation with OpenSSL 1.1.0
  * Registration: added Resource Constraint error condition (thanks to elexis1987) (#267)
  * ConnectionTCP: fixed some blocking (thanks to Marco Ciprietti)
* Tue Jan 24 2017 rpm@fthiessen.de
- Added configure flag to build with getaddrinfo
  instead of deprecated gethostbyname.
* Tue Jan 24 2017 rpm@fthiessen.de
- Update to 1.0.18
  * Message: removed bogus hard-coded namespace to fix component use
  * TLSOpenSSL: fixed wildcard certificate support
  * Pubsub::Event: fixed potential NULL dereference
  * ConnectionTCPServer: fixed listening on local socket
  * Adhoc: fixed memory leak (thanks to Erik Horemans)
  * ConnectionTLS: delete old connection in setConnectionImpl()
    (thanks to Erik Horemans) and clarify this in the documentation
  * Tag: Android compilation fix (thanks to Erik Horemans)
  * ConnectionSOCKS5Proxy: improved compatibility
    (thanks to Erik Horemans)
  * util: Android compilation fix (thanks to Erik Horemans)
  * Client, ClientBase: avoid ‘from’ attribute when doing
    resource binding
  * MUCRoom: allow empty message body if extension is present
    (#264) (thanks to Tom Quackenbush)
  * ConnectionBOSH: initialize ‘hold’ to 1 to improve compatibility
  * ConnectionTCPServer: actually accept incoming connections
* Sun Aug 28 2016 jengelh@inai.de
- Kill off extraneous Provide tags
* Fri Jul 29 2016 mailaender@opensuse.org
- new upstream version 1.0.16 (see ChangeLog)
- rename package from libgloox to gloox
- enable tests
* Sun May 22 2016 dap.darkness@gmail.com
- Removed %%%%debug_package to pass openSUSE:Factory:Staging.
  By the way this practise is ugly nowadays, OBS provides debug flags.
* Tue Sep  8 2015 aj@ajaissle.de
- Update to 1.0.14
  * IOData: make it possible to pass more than one element as in/out/error data
  * Client: fix resetting of presence status text
  * TLSSChannel: fix memory leak (thanks to Alexander Weisner)
  * Error: added setAppError() to set application-specific error message
  * PubSub::Item: added setPayload(), setID()
  * Adhoc: return clone of plugin
  * PubSub::Manager: fix finding of subscription type (thanks to BillHoo)
  * ChatStateFilter: fix enable logic (thanks to Ivan Shmakov)
  * MessageEvent: added parsing of (thanks to Ivan Shmakov)
  * MessageEvent: added id() (thanks to Ivan Shmakov)
  * ClientBase: handle MUC invitation declines properly (thanks to Matias Snellingen)
  * DNS: IPv6 fix (thanks to garimacoe) (#249)
  * DelayedDelivery: propagate internal state properly (#251)
  * PubSub::Manager: fix GetSubscriberList and GetAffiliateList
* Sun Apr  5 2015 aj@ajaissle.de
- Update to 1.0.13
  * fixed compilation with libressl (thanks to Heiko Becker)
  * added IO Data (XEP-0244)
  * serialise access to compressionZlib::cleanup for thread safety (thanks to Stephen Hilliard)
  * prevent infinite loop in Tag::setCData() (thanks to Stephen Hilliard)
  * TLSOpenSSL: memory leak on every client connection attempt (thanks to Stephen Hilliard)
  * Client: initialize m_smWanted to avoid connection failures (thanks to Stephen Hilliard)
* Thu Dec 11 2014 aj@ajaissle.de
- Update to 1.0.12
  - TLSOpenSSLClient/Server: disabled SSLv3
- version 1.0.11 released: 13 Sep 2014
  - GnuTLS: updated use of priority API
  - LinkLocal*: compile fixes for MSVC 2008 (thanks to Serhiy M. Vasylenko)
  - fixed Debian bug #746857, worked around #758899
  - fixed memory leak (#240)
  - fixed compatibility with recent GnuTLS versions, fixed GnuTLS check (thanks to Andreas Metzler) (#231)
  - Jingle::Session: fixed state error (thanks to leerymatthew) (#236)
- version 1.0.10 released: 09 Apr 2014
  - TLSSChannel: use malloc/realloc/free instead of their legacy Local* variants (fixes #222)
  - VCard: remove \r from vcard photos. Fixes a recent change Facebook made to their vcard pictures (patch by Fernando Sanchez)
  - Jingle: fixed replying; distinguish between ‘from’ and ‘initiator'; added Jingle::Session::setInitiator()
  - Jingle: fixed ::ICEUDP to actually add candidates; added ::Session::initiator(), ::setHandler(), ::sessionAccept( PluginList ); fixed storing of new sessions in ::SessionManager (patches by Erich Keane)
  - Jingle: removed Jingle::setInitiator() and ::setResponder() (now provided by ctor)
  - AtomicRefCount: fixed compilation on iOS (patch by Erich Keane)
  - Jingle::Plugin: added JinglePluginType, pluginType(), and findPlugin() to easily look for and retrieve specific plugins
  - ConnectionBOSH: fixed return value for recv() (patch by Sudarshan Prasad)
  - Parser: get rid of bogus isValid() (fixes #180, #224)
- Drop gloox-1.0.9_long_long.patch (using sed)
* Wed Jan 22 2014 aj@ajaissle.de
- Update to 1.0.9 (new soname 11)
- gloox-1.0.9_long_long.patch -- Add -Wno-long-long to Makefiles
- License changed from GPLv2 to GPLv3
- version 1.0.9 released: 15 Oct 2013
  + changed colon to dash in uid generation to possibly fix #191
  + added Channel Binding (needed for SASL SCRAM-SHA-1-PLUS) to SChannel on win32 (untested)
  + fixed SCRAM-SHA-1-PLUS
- version 1.0.8 released: 15 Oct 2013
  + ConnectionTLS: make stacked TLS/SSL connections work again with HTTP proxies
  + added SASL SCRAM-SHA-1/SCRAM-SHA-1-PLUS authentication mechanisms (GnuTLS & OpenSSL only) (#201)
  + properly seed the RNG
  + SHA::hex(): finalize() only once
- version 1.0.7.1 released: 11 Oct 2013
  + fixed/updated the win32 project files
- version 1.0.7 released: 11 Oct 2013
  + added Jingle (XEP-0166)
  + added Jingle ICE-UDP Transport (XEP-0176)
  + added Jingle File Transfer (XEP-0234)
  + fixed compilation in iOS7 SDK (thanks to Kurt Vermeersch)
  + fixed bug in stanza handling/counting related to Stream Management (patch by Norbert Riedlin)
  + added protected ClientBase::stanzasSent() to return sent stanzas (if Stream Management enabled)
- version 1.0.6 released: 04 Sep 2013
  + ClientBase: removed check for empty message body –> messages of type chat with empty bodies will be passed on to listeners – required for Message Carbons
  + MessageSession: removed check for empty message body –> messages of type chat with empty bodies will be passed on to listeners – required for Message Carbons
  + don’t send presence after stream resumption
  + added ClientBase::sendQueue()
  + documentation updates and fixes
- version 1.0.5 released: 02 Sep 2013
  + added support for Stanza Forwarding (XEP-0297)
  + added support for Message Carbons (XEP-0280)
- version 1.0.4 released: 30 Aug 2013
  + added support for Stream Management (XEP-0198)
  + Fix some iterator usage for portability related to erase (patch by Daniel Bowen)
  + Ensure setting a connection does not leave a deleted value in the member variable for a time (patch by Daniel Bowen)
  + Add operator< and relatives to JID so that it can be in a map (patch by Daniel Bowen)
  + Sandboxing on Apple doesn’t like getprotobyname (patch by Daniel Bowen)
  + MessageSession::send(): removed default argument of 2nd parameter to remove ambiguity of MS::send( string ) (#206) (source incompatible!)
  + VCard: renamed setPhoto( string ) to setPhotoUri( string ) (#166) (source and binary incompatible)
- version 1.0.3 released: 22 Jul 2013
  + changed license to GPLv3
  + removed space from VS project name (–> gloox-1.0)
  + VCardUpdate: fixed handling of empty hash (#203)
  + VCardUpdate: added hasPhoto() to inidicate whether there was a photo tag (#203)
  + compilation fixed when using getaddrinfo (patch by Roy van Dam)
  + Receipt: recognize id attribute (patch by Dídac Pérez) (#208)
  + MessageSession: added MS::send( string& ) to properly provide a base for MUCMS::send( string& ) (#206)
  + really fixed memory leak in prep::idna()
  + gloox.vcproj: removed not-yet-present tlsgnutlsserver.cpp/.h
- version 1.0.2 released: 05 Jul 2013
  + SOCKS5Bytestream: Don’t wait for incoming data, notify about open stream immediately upon
  + connection (patch by Erik Horemans)
  + fixed/updated Code::Blocks and VS project files (fixes #197, #198)
  + fixed memory leak in ClientBase (fixes #204)
  + fixed memory leak in prep::idna()
- version 1.0.1 released: 29 Jun 2013
  + added support for Serverless Messaging (XEP-0174)
  + TLSOpenSSLServer: compilation fix
  + don’t bail on DNS TCP queries
  + fixed µs timeout value (now defaults to 1.000.000)
  + omit port in initial greeting (usually -1 anyway)
  + fixed SHA1 hashes of 55 byte strings (#164)
  + fixed CFLAGS and LIBS in pkg-config file (#163)
  + fixed SOCKS5Bytestream double close notification
  + tell gcrypt that we’re using pthreads (if available)
  + ClientBase: send IQ error response for unsupported features
  + ClientBase: fixed potential infinite loop on IQ error
  + ClientBase: fixed NTLM auth
  + ClientBase, SEF: mutex-protected SE handling
  + PubSub: added ‘subscribe & configure’
  + PubSub: added optional subid
  + SOCKS5BytestreamServer: expose local socket
  + RosterManager: don’t use string-comparison on JIDs; use JID class
  + NonSASLAuth: fixed resource usage by deprecating ClientBase::m_selectedResource
  + InBandBytestream: don’t call handler in dtor
  + util: fixed long2string()
  + fixed a few leaks in GnutTLS client code (#181)
  + VCard: made getters const (#186) (binary-incompatible change!)
  + PubsubManager: fixed using wrong Tag (#190)
  + Search: fixed search() (#193)
  + DNS: fix socket leak if no network connection is available (#192)
  + PubsubManager: unconditionally call handleItemPublication() (#194)
  + configure: Added -lgcrypt (dependency of GNUTLS)
* Tue Dec 11 2012 fisiu@opensuse.org
- Spec file cleanup.
- Drop 'licenses' from Build/Requires.
* Sun Nov  1 2009 pascal.bleser@opensuse.org
- update to 1.0:
  * SONAME bumped from 7 to 8
* Thu Sep 24 2009 pascal.bleser@opensuse.org
- update to 0.9.9.10:
  * fixes a crash in the roster manager
  * fixes the configure check for GnuTLS
* Mon Jul 27 2009 pascal.bleser@opensuse.org
- update to 0.9.9.9
* Fri Mar 21 2008 pascal.bleser@opensuse.org
- update to 0.9.9.7
* Fri Mar  7 2008 guru@unixtech.be
- update to 0.9.9.5, minor bugfixes
* Thu Jan 17 2008 guru@unixtech.be
- update to 0.9.9.4, minor bugfixes
* Wed Jan 16 2008 guru@unixtech.be
- update to 0.9.9.3
* Fri Dec  7 2007 guru@unixtech.be
- update to 0.9.9.2
* Wed Oct 24 2007 guru@unixtech.be
- update to 0.9.8
* Sun Oct 14 2007 guru@unixtech.be
- update to 0.9.6.1
* Wed Aug 15 2007 guru@unixtech.be
- added Requires: libstdc++-devel
- Shared Library Policy (with backwards compatible Provides)
- update to 0.9.5
* Tue Aug 14 2007 guru@unixtech.be
- update to 0.9.4.1
* Fri Jul 20 2007 guru@unixtech.be
- update to 0.9.4
* Sat Jun 23 2007 guru@unixtech.be
- update to 0.9.3
* Wed Jun 20 2007 guru@unixtech.be
- update to 0.9.2
* Mon Jun 18 2007 guru@unixtech.be
- update to 0.9.1
* Fri Jun  8 2007 guru@unixtech.be
- update to 0.9
